# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
def configuration(parent_package='',top_path=None):
    from numpy.distutils.misc_util import Configuration
    config = Configuration('fixes', parent_package, top_path)
    config.add_subpackage('sympy')
    config.add_subpackage('sympy.utilities')
    config.add_subpackage('numpy')
    config.add_subpackage('numpy.testing')
    return config

if __name__ == '__main__':
    from numpy.distutils.core import setup
    setup(**configuration(top_path='').todict())
